@@ -4,7 +4,7 @@ __all__ = [
     'get_closest_topics', 'get_top_topic_words',
     'get_top_topic_docs']
 
-from typing import List, Union, Tuple, Dict
+from typing import List, Union, Tuple, Dict, Sequence, Any
 from scipy.sparse import csr
 from pandas import DataFrame, Series, concat
 from sklearn.feature_extraction.text import CountVectorizer
@@ -32,7 +32,7 @@ def get_words_freqs(
     Returns
     -------
     Tuple[csr.csr_matrix, np.ndarray]
-        Words vs documents matrix in CSR format and vocabulary.
+        Documents vs words matrix in CSR format and vocabulary.
 
     Example
     -------
@@ -171,7 +171,8 @@ def get_closest_topics(
         4) "jef" - Jeffrey's divergence.
         5) "hel" - Hellinger distance.
         6) "bhat" - Bhattacharyya distance.
-        6) "jac" - Jaccard index.
+        7) "tv" - Total variation distance.
+        8) "jac" - Jaccard index.
     top_words : int = 100
         Number of top words in each topic to use in Jaccard index calculation.
     verbose : bool = True
@@ -218,17 +219,21 @@ def get_closest_topics(
 
                 if method == "klb":
                     val_raw = ssp.kl_div(matrix_ref[t_ref, :], matrix[t, :])
-                    all_vs_all_dists[t_ref, t] = val_raw[np.isfinite(val_raw)].sum()
+                    all_vs_all_dists[t_ref, t] = val_raw[
+                        np.isfinite(val_raw)].sum()
 
                 elif method == "sklb":
                     val_raw = ssp.kl_div(matrix_ref[t_ref, :], matrix[t, :])\
                         + ssp.kl_div(matrix[t, :], matrix_ref[t_ref, :])
-                    all_vs_all_dists[t_ref, t] = val_raw[np.isfinite(val_raw)].sum()
+                    all_vs_all_dists[t_ref, t] = val_raw[
+                        np.isfinite(val_raw)].sum()
 
                 elif method == "jsd":
-                    val_raw = 0.5 * ssp.kl_div(matrix_ref[t_ref, :], matrix[t, :])\
+                    val_raw = 0.5 * ssp.kl_div(
+                        matrix_ref[t_ref, :], matrix[t, :])\
                         + 0.5 * ssp.kl_div(matrix[t, :], matrix_ref[t_ref, :])
-                    all_vs_all_dists[t_ref, t] = val_raw[np.isfinite(val_raw)].sum()
+                    all_vs_all_dists[t_ref, t] = val_raw[
+                        np.isfinite(val_raw)].sum()
 
                 elif method == "jef":
                     p = matrix_ref[t_ref, :]
@@ -254,6 +259,12 @@ def get_closest_topics(
                     dist = -np.log(np.sum(np.sqrt(pq)))
                     all_vs_all_dists[t_ref, t] = dist
 
+                elif method == "tv":
+                    p = matrix_ref[t_ref, :]
+                    q = matrix[t, :]
+                    dist = np.sum(np.abs(p - q)) / 2
+                    all_vs_all_dists[t_ref, t] = dist
+
                 elif method == "jac":
                     a = np.argsort(matrix_ref[t_ref, :])[:-top_words-1:-1]
                     b = np.argsort(matrix[t, :])[:-top_words-1:-1]
@@ -343,7 +354,7 @@ def get_stable_topics(
 def get_top_topic_words(
         model: BTM,
         words_num: int = 20,
-        topics_idx: Union[List[int], np.ndarray] = None) -> DataFrame:
+        topics_idx: Sequence[Any] = None) -> DataFrame:
     """Select top topic words from a fitted model.
 
     Parameters
@@ -383,21 +394,21 @@ def get_top_topic_words(
 
 
 def get_top_topic_docs(
-        docs: Union[List[str], np.ndarray],
+        docs: Sequence[Any],
         p_zd: np.ndarray,
         docs_num: int = 20,
-        topics_idx: Union[List[int], np.ndarray] = None) -> DataFrame:
+        topics_idx: Sequence[Any] = None) -> DataFrame:
     """Select top topic docs from a fitted model.
 
     Parameters
     ----------
-    docs : Union[List[str], np.ndarray]
+    docs : Sequence[Any]
         Iterable of documents (e.g. list of strings).
     p_zd : np.ndarray
         Documents vs topics probabilities matrix.
     docs_num : int = 20
         The number of documents to select.
-    topics_idx : Union[List, numpy.ndarray] = None
+    topics_idx : Sequence[Any] = None
         Topics indices. Meant to be used to select only stable
         topics.
 
